@@ -1,6 +1,6 @@
 import os
 import shutil
-import puke.Console
+from puke.Console import *
 
 def makedir(dirname):
     """ Creates missing hierarchy levels for given directory """
