@@ -153,10 +153,10 @@ def deepcopy(file_list, folder, replace = None):
     for (file, basepath) in file_list:
         
         if basepath:
-            dst_file = file.replace(basepath, '').strip('/')
+            dst_file = __pretty(file).replace(basepath, '').strip('/')
             dst_file = os.path.join(folder,dst_file)
         else:
-            dst_file = os.path.join(folder,os.path.basename(file))
+            dst_file = os.path.join(folder,os.path.basename(__pretty(file)))
 
         #console.warn("File : " + file +  " dest " + dst_file)
 
