@@ -93,6 +93,7 @@ def run():
             raise PukeError("No generate file '%s' found!" % options.file)
         else:
             raise PukeError("No generate file found!")
+    
 
     retval = execfile(script)
 
@@ -140,8 +141,9 @@ def main():
         run()
     
     except Exception as error:
+        exc_type, exc_obj, exc_tb = sys.exc_info()
 
-        console.fail("\n\n :puke: \n PUKE %s\n" % error)
+        console.fail("\n\n :puke: \n PUKE %s ( line : %s)\n" % (error, exc_tb.tb_lineno))
 
         sys.exit(1)
         
